
/* Ekiga -- A VoIP and Video-Conferencing application
 * Copyright (C) 2000-2006 Damien Sandras
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *
 * Ekiga is licensed under the GPL license and as a special exception,
 * you have permission to link or otherwise combine this program with the
 * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
 * without applying the requirements of the GNU GPL to the OPAL, OpenH323
 * and PWLIB programs, as long as you do follow the requirements of the
 * GNU GPL for all the rest of the software thus combined.
 */


/*
 *  Authors: Jorn Baayen <jorn@nl.linux.com>
 *           Kenneth Christiansen <kenneth@gnu.org>
 */

#ifndef __GM_STOCK_ICONS_H
#define __GM_STOCK_ICONS_H

G_BEGIN_DECLS

#define GM_STOCK_16               "gm_16_stock"
#define GM_STOCK_ADDRESSBOOK_16   "gm_addressbook_16_stock"
#define GM_STOCK_ADDRESSBOOK_24   "gm_addressbook_24_stock"
#define GM_STOCK_TEXT_CHAT        "gm_text_chat_stock"
#define GM_STOCK_CONTROL_PANEL    "gm_control_panel_stock"
#define GM_STOCK_CONNECT          "gm_connect_stock"
#define GM_STOCK_DISCONNECT       "gm_disconnect_stock"
#define GM_STOCK_EDIT             "gm_edit_stock"
#define GM_STOCK_VIDEO_PREVIEW    "gm_video_preview_stock"
#define GM_STOCK_AUDIO_MUTE       "gm_audio_mute_stock"
#define GM_STOCK_VOLUME           "gm_volume_stock"
#define GM_STOCK_MICROPHONE       "gm_microphone_stock"
#define GM_STOCK_SPEAKER_PHONE    "gm_speaker_phone_stock"
#define GM_STOCK_VIDEO_MUTE       "gm_video_mute_stock"
#define GM_STOCK_STATUS_AVAILABLE "gm_status_available_stock"
#define GM_STOCK_STATUS_DO_NOT_DISTURB "gm_status_do_not_disturb_stock"
#define GM_STOCK_STATUS_IN_A_CALL "gm_status_in_a_call_stock"
#define GM_STOCK_STATUS_FORWARD   "gm_status_forward_stock"
#define GM_STOCK_STATUS_OFFLINE   "gm_status_offline_stock"
#define GM_STOCK_STATUS_AUTO_ANSWER "gm_status_auto_answer_stock"
#define GM_STOCK_STATUS_RINGING   "gm_status_ringing_stock"
#define GM_STOCK_LOCAL_CONTACT    "gm_local_contact_stock"
#define GM_STOCK_REMOTE_CONTACT   "gm_remote_contact_stock"
#define GM_STOCK_CONTRAST         "gm_contrast_stock"
#define GM_STOCK_WHITENESS        "gm_whiteness_stock"
#define GM_STOCK_BRIGHTNESS       "gm_brightness_stock"
#define GM_STOCK_COLOURNESS       "gm_colourness_stock"
#define GM_STOCK_CONNECT_16       "gm_connect_16_stock"
#define GM_STOCK_DISCONNECT_16    "gm_disconnect_16_stock"
#define GM_STOCK_CALLS_HISTORY    "gm_calls_history_stock"
#define GM_STOCK_MESSAGE          "gm_message_stock"


void gnomemeeting_stock_icons_init (void);

G_END_DECLS

#endif /* __GM_STOCK_ICONS_H */
